<?php
namespace App\Controller;

use App\Controller\AppController;
use Cake\Network\Http\Client;
use Cake\I18n\Time;
/**
 * CarteiraAlunos Controller
 *
 * @property \App\Model\Table\CarteiraAlunosTable $CarteiraAlunos
 */
class CarteiraAlunosController extends AppController
{

    public function beforeFilter(\Cake\Event\Event $event) {
        parent::beforeFilter($event);
        $this->Auth->allow(['statusPagSeguro']);

        $this->loadComponent('PagSeguro');
    }


    /**
     * Index method
     *
     * @return \Cake\Network\Response|null
     */
    public function aluno()
    {
        $carteiraAluno = $this->CarteiraAlunos->get($this->Auth->User()['id'], [
            'contain' => []
        ]);

        $this->loadModel('Carteiras');
        $carteiras = $this->Carteiras->find('all',['conditions'=>['COD_ESCOLA'=>$this->Auth->User()['clients_id']]]);

        /*debug($this->PagSeguro->paymentRequest($carteiraAluno,'http://'.$_SERVER['SERVER_NAME'].$this->request->webroot));*/

        if ($this->request->is(['patch', 'post', 'put'])) {
            
            $fotodb = $carteiraAluno->ca_foto;

            $resultEdit = null;
            $carteiraAluno = $this->CarteiraAlunos->patchEntity($carteiraAluno, $this->request->data);


            if($this->request->data['image-file']['size'] != 0 || $this->request->data['resetFile'] == 'true'){


                $crop = [
                    'x1'=>$this->request->data['x1'],
                    'x2'=>$this->request->data['x2'],
                    'y1'=>$this->request->data['y1'],
                    'y2'=>$this->request->data['y2'],
                    'w'=>$this->request->data['w'],
                    'h'=>$this->request->data['h'],
                    'wp'=>$this->request->data['wp'],
                ];


                $resultEdit = $this->editImage('photos',$this->request->data['image-file'],$fotodb,true,null,true,$crop);   
                $carteiraAluno->ca_foto = $resultEdit['image'];

            }   



            if(!isset($resultEdit['errors'])){

                if ($this->CarteiraAlunos->save($carteiraAluno)) 
                    $this->Flash->success(__('Carteira aluno alterada')); 
                else 
                    $this->Flash->error(__('Erro ao fazer alteração, por favor tente novamente'));
            }else
                    $this->Flash->error($resultEdit['errors'][0]);
           // return $this->redirect(['action' => 'index']);
            
        }

        $this->set(compact('carteiras'));
        $this->set(compact('carteiraAluno'));
        $this->set('_serialize', ['carteiraAluno','carteiras']);
    }

    /**
     * View method
     *
     * @param string|null $id Carteira Aluno id.
     * @return \Cake\Network\Response|null
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    private function view($id = null)
    {
        $carteiraAluno = $this->CarteiraAlunos->get($id, [
            'contain' => []
        ]);

        $this->set('carteiraAluno', $carteiraAluno);
        $this->set('_serialize', ['carteiraAluno']);
    }

    /**
     * Add method
     *
     * @return \Cake\Network\Response|void Redirects on successful add, renders view otherwise.
     */
    private function add()
    {
        $carteiraAluno = $this->CarteiraAlunos->newEntity();
        if ($this->request->is('post')) {
            $carteiraAluno = $this->CarteiraAlunos->patchEntity($carteiraAluno, $this->request->data);
            if ($this->CarteiraAlunos->save($carteiraAluno)) {
                $this->Flash->success(__('The carteira aluno has been saved.'));

                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error(__('The carteira aluno could not be saved. Please, try again.'));
            }
        }
        $this->set(compact('carteiraAluno'));
        $this->set('_serialize', ['carteiraAluno']);
    }

    /**
     * Edit method
     *
     * @param string|null $id Carteira Aluno id.
     * @return \Cake\Network\Response|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    private function edit($id = null)
    {
        $carteiraAluno = $this->CarteiraAlunos->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $carteiraAluno = $this->CarteiraAlunos->patchEntity($carteiraAluno, $this->request->data);
            if ($this->CarteiraAlunos->save($carteiraAluno)) {
                $this->Flash->success(__('The carteira aluno has been saved.'));

                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error(__('The carteira aluno could not be saved. Please, try again.'));
            }
        }
        $this->set(compact('carteiraAluno'));
        $this->set('_serialize', ['carteiraAluno']);
    }

    /**
     * Delete method
     *
     * @param string|null $id Carteira Aluno id.
     * @return \Cake\Network\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    private function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $carteiraAluno = $this->CarteiraAlunos->get($id);
        if ($this->CarteiraAlunos->delete($carteiraAluno)) {
            $this->Flash->success(__('The carteira aluno has been deleted.'));
        } else {
            $this->Flash->error(__('The carteira aluno could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }



    public function geraPdf($modo = "I"){


        $carteiraAluno = $this->CarteiraAlunos->get($this->Auth->User()['id'], [
           // 'contain' => ['Students']
        ]);

        $this->loadModel("Students");
        $student = $this->Students->get($this->Auth->User()['id']);

        $this->loadModel("Offices");
        $office = $this->Offices->find('all',['conditions'=>['clients_id'=>$student->clients_id,'off_type_office'=>2,'off_status'=>1],'contain'=>'Insurers'])->first();

        if($office){
            $student->off_num_apolice_1 = $office->off_num_apolice_1;
            $student->insurer_id = ($office->insurer) ? $office->insurer->id : '1';
        }else {
            $student->off_num_apolice_1 = "";
            $student->insurer_id = 1;
        }

        $student->stu_name = $this->valida_nome($student->stu_name);
        if($carteiraAluno->ca_email == ""){
            $this->Flash->error(__('Obrigatório preencher o campo email para continuar'));
            return $this->redirect(['action' => 'aluno']);
        }
        if(!$carteiraAluno->ca_foto){
            $this->Flash->error(__('Obrigatório foto para prosseguir'));
            return $this->redirect(['action' => 'aluno']);
        }
        
        if($carteiraAluno->ca_impressao == 0){
            //add 1 impressao e salva
            if($carteiraAluno->cod_aluno != "8888888")
                $carteiraAluno->ca_impressao = 1;
            $this->CarteiraAlunos->save($carteiraAluno);
        }else{
            $this->Flash->error(__('Por sua segurança impressão só é permitida uma vez, dúvidas entre em contato'));
            return $this->redirect(['action' => 'aluno']);
        }

        $this->set('student',$student);
        $this->set('carteiraAluno',$carteiraAluno);
        $this->set('_serialize', ['carteiraAluno','student']);
        

        $this->set('modoPrint',$modo);
        
    
    }
    public function geraPdfDigital($modo = "I"){

        ini_set('memory_limit', '-1');

        $this->autoRender = false;


        $carteiraAluno = $this->CarteiraAlunos->get($this->Auth->User()['id'], [
            //'contain' => ['']
        ]);
        $this->loadModel("Students");
        $student = $this->Students->get($this->Auth->User()['id']);




        $this->loadModel("Offices");
        $office = $this->Offices->find('all',['conditions'=>['clients_id'=>$student->clients_id,'off_type_office'=>2,'off_status'=>1],'contain'=>'Insurers'])->first();


        if($office){
            $student->off_num_apolice_1 = $office->off_num_apolice_1;
            $student->insurer_id = ($office->insurer) ? $office->insurer->id : '1';
        }else {
            $student->off_num_apolice_1 = "";
            $student->insurer_id = 1;
        }

        $student->stu_name = $this->valida_nome($student->stu_name);

        if($carteiraAluno->ca_email == ""){
            
            $this->Flash->error(__('Obrigatório preencher o campo email para continuar'));
            return $this->redirect(['action' => 'aluno']);
        }

        var_dump($carteiraAluno);

        $this->set('carteiraAluno',$carteiraAluno);
        $this->set('student',$student);
        $this->set('_serialize', ['carteiraAluno','student']);


        $this->set('modoPrint',$modo);
    
    }



    public function requestPagSeguro(){


        $this->viewBuilder()->layout(false);




        if ($this->request->is(['patch', 'post', 'put'])) {

            $carteiraAluno = $this->CarteiraAlunos->get($this->Auth->User()['id'], [
                'contain' => ['Students']
            ]);


            if($carteiraAluno->ca_foto){

                $email = 'alesvboas@gmail.com';
                $token = '2BF838F874E941FD963DD4AEF37A9344';
                $url = 'https://ws.pagseguro.uol.com.br/v2/checkout/?email=' . $email . '&token=' . $token;
                $xml = '<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
                    <checkout>
                        <currency>BRL</currency>
                        <items>
                            <item>
                                <id>0001</id>
                                <description>Carteira Villas Boas</description>
                                <amount>15.00</amount>
                                <quantity>1</quantity>
                                <weight>1000</weight>
                            </item>
                        </items>
                        <reference>'.$carteiraAluno->cod_aluno.'</reference>
                        <sender>
                            <name>'.str_replace("  ", " ", $carteiraAluno->student->stu_name).'</name>
                            <email>'.$carteiraAluno->ca_email.'</email>
                            
                        </sender>
                        <shipping>
                            <type>2</type>
                        </shipping>
                    </checkout>';

                /*
                1	Encomenda normal (PAC)
				2	SEDEX
				3	Tipo de frete não especificado
				*/

                $curl = curl_init($url);
                curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
                curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($curl, CURLOPT_HTTPHEADER, Array('Content-Type: application/xml; charset=ISO-8859-1'));
                curl_setopt($curl, CURLOPT_POSTFIELDS, $xml);
                $xml= curl_exec($curl);



                if($xml != 'Unauthorized'){
                    $xml= simplexml_load_string($xml);


                    if(!isset($xml->error)){
                        $code = (string) $xml->code;
                        $objJson['code'] = $code;
                    }
                    else{
                        $objJson['error'] = true;
                        $objJson['message'] = (string) $xml->error->message;
                    }

            
                    $this->set('request',$objJson);
                    
                }else{
                    $this->Flash->error(__('Erro ao autenticar PagSeguro, entre em contato'));
                    $this->set('request',["error"=>'auth']);
                }

            }else{
                $this->Flash->error(__('Obrigatório foto para prosseguir'));
                $this->set('request',["error"=>'foto']);
            }
        }

    }


    public function retornoPs($transaction = null){





    }


    public function statusPagSeguro(){


        $this->autoRender = false;

        if ($this->request->is('post')) {
            //$this->log($this->request->data);



            $notificationCode = $this->request->data['notificationCode'];
            $notificationType = $this->request->data['notificationType'];
            //[notificationCode] => AE9497-5883E083E0DD-C2241EBFAA21-C0D79E
            //[notificationType] => transaction
            //$transactionCode = "F3A1ADFE46234B2FB07A5D30B8E9C672";

            $http = new Client([
                'ssl_verify_peer'=>false,            
                'ssl_verify_host'=>false,
                'timeout'=>5,
                'ssl_verify_peer_name'=>false]);


            //$response = $http->get("https://ws.pagseguro.uol.com.br/v3/transactions/$transactionCode?email=alesvboas@gmail.com&token=2BF838F874E941FD963DD4AEF37A9344");

            $response = $http->get("https://ws.pagseguro.uol.com.br/v3/transactions/notifications/$notificationCode?email=alesvboas@gmail.com&token=2BF838F874E941FD963DD4AEF37A9344");

            //$response = $http->get("https://ws.sandbox.pagseguro.uol.com.br/v3/transactions/notifications/$notificationCode?email=alesvboas@gmail.com&token=243BE310A5B04633B3DA92FB0F133FE9");

            // BUSCA ALUNO DE ACORDO COM EMAIL
            $carteiraAluno = $this->CarteiraAlunos->get($response->xml->reference, [
            'contain' => ['Students']
            ]);    

            $this->log('PAG SEGURO');
            //$this->log($response->xml);

            //$idOrc = $response->xml->reference;
            $paymentPS = $response->xml->paymentMethod->type;
            $statusPS = $response->xml->status;         
            $transaction = $response->xml->code;         
        // Trata status , pagamento etc.

            $carteiraAluno->transaction_code = (string) $transaction;
            $carteiraAluno->payment_status = (int) $statusPS;

            $this->CarteiraAlunos->save($carteiraAluno);


            if($statusPS <= 2) // aguardando pagamento Cartão
                $status = "Aguardando pagamento ";
            if($statusPS == 3) // pagamento aprovado{
                $status = "Pagamento Aprovado";
            if($statusPS == 4) // pagamento aprovado{
                $status = "Disponível PAG SEGURO";
            if($statusPS == 5) // pagamento não autorizado
                $status = "Pagamento Não autorizado";
            if($statusPS > 5) // pagamento cancelado
                $status = "Pagamento cancelado";

            if($paymentPS == 1)
                $pagamentoForma = "Cartão de crédito";
            if($paymentPS == 2)
                $pagamentoForma = "Boleto Bancário";
            if($paymentPS == 3)
                $pagamentoForma = "Débito Online";
            if($paymentPS == 4)
                $pagamentoForma = "Saldo PagSeguro";
            if($paymentPS == 5)
                $pagamentoForma = "Oi Paggo";
            if($paymentPS == 7)
                $pagamentoForma = "Deposito em conta";


            $nome = $response->xml->sender->name;
            $email = $response->xml->sender->email;

            //ENDERECO;
            $address = [
            'street' => $response->xml->shipping->address->street,
            'number' => $response->xml->shipping->address->number,
            'complement' => $response->xml->shipping->address->complement,
            'district' => $response->xml->shipping->address->district,
            'city' => $response->xml->shipping->address->city,
            'state' => $response->xml->shipping->address->state,
            'country' => $response->xml->shipping->address->country,
            'postalCode' => $response->xml->shipping->address->postalCode,
            'type' => $response->xml->shipping->type,
            'cost' => $response->xml->shipping ->cost,
            ];
            /*
            1   Encomenda normal (PAC).
            2   SEDEX.
            3   Tipo de frete não especificado.
            */




            if($address['type'] == 1)
                $tipoFrete = "Encomenda normal (PAC)";
            if($address['type'] == 2)
                $tipoFrete = "SEDEX";
            if($address['type'] == 3)
                $tipoFrete = "Tipo de frete não especificado.";

            $date = $response->xml->date;
            $date = Time::parse($date);
            $body = '<img src="http://'.$_SERVER['SERVER_NAME'].$this->request->webroot.'img/logo_header.png" style="float:left" /><h2>Pedido efetuado </h2>

            <h4>Status: :<span style="color:#00F">'. $status .'</span></h4>
            <div style="clear:both"></div>
            <p><strong>Data pedido:</strong>'.$date->format('d/m/Y H:i').'<br>
            <strong>Forma:</strong>'.$pagamentoForma.'<br><Br>
            <strong>Total:</strong>'.$response->xml->grossAmount.'<br></p>

            <strong>Nome: </strong>'.$nome.' <br>
            <strong>Email: </strong>'.$email.'</p><br>
            <h3>Aluno</h3>
            <strong>Nome: </strong>'.$carteiraAluno->student->stu_name.'<br>
            <strong>Codigo: </strong>'.$carteiraAluno->cod_aluno.'</p><br>
            <strong>Escola: </strong>'.$carteiraAluno->student->clients_id.'</p><br>

            <h4>Endereço Entrega</h4>
            <p><strong>Rua: </strong>'.$address['street'].' '.$address['number'].' '.$address['complement'].'<br>
            <strong>Cidade: </strong>'.$address['city'].' - '.$address['state'].'<Br>
            <strong>CEP:</strong>'.$address['postalCode'].'<br>
            <strong>Frete: </strong>'.$tipoFrete.' Valor: R$ '.$address['cost'].'<Br></p><BR><BR>';



            require_once('phpMailer/PHPMailerAutoload.php');

            $mail = new \PHPMailer();


            $mail->IsSMTP(); // Define que a mensagem será SMTP
            $mail->Host = "smtpexc01.redehost.com.br"; // Endereço do servidor SMTP
            $mail->SMTPAuth = true; // Autenticação
            $mail->Username = 'cobranca@villasboasseguros.com.br'; // Usu�rio do servidor SMTP
            $mail->Password = 'CO#$VBS2015'; // Senha da caixa postal utilizada
            $mail->Port = 587;

            $mail->SMTPSecure = 'tls';
            // Define o remetente
            $mail->SMTPDebug = 2;
            //$mail->Debugoutput = 'html';
            //$mail->SMTPSecure = 'ssl';  // SSL REQUERIDO pelo GMail
            //$mail->SMTPSecure = 'ssl';  

            $mail->setFrom('cobranca@villasboasseguros.com.br', 'Carteira VillasBoas');
            $mail->FromName = "Carteira VB";  
            // Define os destinatário(s) 
            $mail->addAddress('atendimento@villasboasseguros.com.br', 'VillasBoas Carteira');


            if($statusPS != 4){
                $mail->addAddress($email); // para o cliente
           
                //$mail->addBCC('awd.contato@gmail.com', 'VILLAS-SITE'); // copia oculta
                $mail->addBCC('alexandre@m2comunicacoes.com.br', 'VILLAS-SITE'); // copia oculta
                

                //
                // Define os dados técnicos da Mensagem
                $mail->IsHTML(true); // Define que o e-mail será enviado como HTML
                $mail->CharSet = 'UTF-8'; // Charset da mensagem (opcional)
                // Texto e Assunto
                $mail->Subject  = 'Pedido PagSeguro - Carteira VB'; // Assunto da mensagem
                $mail->Body = $body;

                //verifica STATUS DO PEDIDO
                if($statusPS == 3){   
                    $mail->addAttachment('photos/thumb/t_'.$carteiraAluno->ca_foto);    
                }
                
                $enviado = $mail->send();
                // Limpa os destinatários e os anexos

                $mail->ClearAllRecipients();
                $mail->ClearAttachments();

                if($enviado)
                    echo "email enviado";
            }

            // envia um email avisando do pedido PS

           // envia email se pago com foto do aluno
            echo "OK";
        }
        else 
            return $this->redirect('/');
        
    }

    public function valida_nome ($Nome,$maximo = 35){

        $Nome = trim($Nome); // remove espaço em branco do final e começo

        // Calcula a quantidade de caracteres do nome
        $quantidade = strlen($Nome);
        //Variavel para fazer a comparacao se passou da quantidade maxima permitida
        $maximo_caracter = $maximo;
        // if para fazer a comparação e decidir se é necessario fazer o tratamento do nome
        if($quantidade<$maximo_caracter){
            return $Nome;
        }

        $Nome = explode(" ", $Nome); // cria o array $nome com as partes da string
        $num = count($Nome); // conta quantas partes o nome tem
        $novo_nome = '';
        // variavel que irá concatenar as partes do nome
        $espacos = " ";

        //Variaveis para controle qual sobrenome o foreach está
        $count = 1;
        foreach($Nome as $var) { // loop no array

            //echo "<br/> Num ".$num."Count ".$count;
            if (($count == 1) || ($count == $num) || $count == 2) {
                $novo_nome .= $var.' '; // Atribui o primeiro nome
                //$count++;
            }


            //Quando for para segunda posição do array, que é o primeiro sobrenome e que não
            //seja maior do que a quantidade de sobrenome do nome

            if(($count >= 3) && ($count < $num)) {
                // Quando aparecer um desses entao nao atribui
                $array = array('do', 'Do', 'DO', 'da', 'Da', 'DA', 'de', 'De', 'DE', 'dos', 'Dos', 'DOS', 'das', 'Das', 'DAS');
                //Compara se a variavel var do foreach tem algum dos conteudos nao permitos
                //do array
                if(in_array($var, $array)) {
                    // não Atribui para o nome novo
                }else {
                    $novo_nome .= substr($var, 0, 1).'. '; // abreviou
                } // fim
            }

            $count++;

        }//Final do Foreach
        return $novo_nome;

    }//Final da Função
}
